/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2024  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#ifndef ACTIVEPROGRAMWIDGETHEADERFILE
#define ACTIVEPROGRAMWIDGETHEADERFILE

#include <QWidget>

class QFrame;
class QLineEdit;
class QPlainTextEdit;

class TActiveProgramWidget : public QWidget
{
Q_OBJECT

public:

// CREATORS
	TActiveProgramWidget(const QWidget *parent=0, Qt::WindowFlags flags=Qt::WindowFlags());
	~TActiveProgramWidget(void);

// ACCESSORS
	int Open_Time(void) const;
	int Idle_Time(void) const;
	int Execution_Time(void) const;

// MANIPULATORS
	void Enable_Collection(const bool state);
	void Set_Name(const QString &text);
	void Set_Revision(const QString &text);
	void Set_Date(const QString &text);
	void Increment_Open_Time_MS(const int milliseconds);
	void Increment_Execution_Time_MS(const int milliseconds);
	void Set_Point_Count(const int count);
	void Set_Last_Error(const QString &text);
	
	void Reset(void);
	
	void Add_Message(const QString &text);

signals:

private slots:

private:
	QFrame								*d_collecting_data_frame;
	QLineEdit							*d_program_name_edit;
	QLineEdit							*d_program_revision_edit;
	QLineEdit							*d_execution_date_edit;
	QLineEdit							*d_open_time_edit;
	QLineEdit							*d_execution_time_edit;
	QLineEdit							*d_idle_time_edit;
	QLineEdit							*d_point_count_edit;
	QLineEdit							*d_last_error_edit;
	QPlainTextEdit						*d_message_text;
	
	int									d_execution_time_milliseconds;
	int									d_open_time_milliseconds;

	void Clear_Messages(void);

	
// NOT IMPLEMENTED
	TActiveProgramWidget(const TActiveProgramWidget&);
	TActiveProgramWidget& operator=(const TActiveProgramWidget&);
};

#endif
