/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2024  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#ifndef CMMUSAGEHEADERFILE
#define CMMUSAGEHEADERFILE

#include <QMainWindow>
#include <QElapsedTimer>

#include "../../core/automation.h"

#include "databaseitem.h"

class QSettings;
class QAction;
class QCloseEvent;
class QStatusBar;
class QPlainTextEdit;
class QTabWidget;
class QTimer;
class QThread;
class TMonitorProcess;
class TDataWidget;
class TDatabase;
class TActiveProgramWidget;
class TSummaryText;
class TMessageBox;

class TCMMUsage : public QMainWindow
{
Q_OBJECT

public:

// CREATORS
	TCMMUsage(const QWidget *parent=0, Qt::WindowFlags flags=Qt::WindowFlags());
	virtual ~TCMMUsage(void);

// ACCESSORS

// MANIPULATORS

signals:

private slots:
	void Toggle_Monitor(void);
	void Suspend_Resume(bool);
	
	void Application_Event(const QString &event_name,int argument_count,TAutomation::TArg * const arguments);
	void Machine_Event(const QString &event_name,int argument_count,TAutomation::TArg * const arguments);
	
	void Export_All_CSV(void);
	void Export_Selected_CSV(void);
	void Export_Selected_TXT(void);

	void Monitor_Started(void);
	void Monitor_Finished(void);
	void Update_Timeout(void);
	
	void Help_About(void);

	void Date_Selection_Changed(const QStringList &list);
	void Program_Selection_Changed(const QStringList &list);
	
	void Summary_Text_Ready(void);

#ifndef Q_OS_WIN
	void Simulation_Timeout(void);
#endif
	
protected:
	virtual void closeEvent(QCloseEvent *event);

private:
	
enum TConnectionStatus
{
	NOT_CONNECTED = 0,
	CONNECTION_IDLE,
	CONNECTED
};

	QAction								*d_connect_disconnect_action;
	QAction								*d_export_all_csv_action;
	QAction								*d_export_selected_csv_action;
	QAction								*d_export_selected_txt_action;
	QTabWidget							*d_view_tab;
	QPlainTextEdit						*d_summary_text;
	QStatusBar							*d_status_bar;
	QSettings							*d_settings;
	TDataWidget							*d_date_data_widget;
	TDataWidget							*d_program_data_widget;
	TDatabase							*d_database;
	TActiveProgramWidget				*d_active_program_widget;
	QTimer 								*d_update_timer;
	QThread								*d_summary_thread;
	TMessageBox							*d_msg_box;
	TSummaryText						*d_summary_text_worker;
	
	TAutomation							*d_pcdmis_application_events;
	TAutomation							*d_pcdmis_machine_events;
	TMonitorProcess						*d_monitor_process;
	
	TAutomation							d_pcdmis;
	TDatabaseItem						d_active_database_item;
	TConnectionStatus					d_connection_status;
	QStringList							d_selected_dates;
	QStringList							d_selected_programs;
	QString								d_pcdmis_path;
	QString								d_data_path;
	QString								d_export_path;
	QElapsedTimer						d_monitor_timer;
	QElapsedTimer						d_software_run_timer;
	QElapsedTimer						d_program_open_timer;
	QElapsedTimer						d_program_execution_timer;
	bool								d_monitor_active;
	bool								d_program_open;
	bool								d_program_executing;
	

#ifndef Q_OS_WIN
	QTimer 								*d_simulation_timer;
	QStringList							d_simulation_events;
#endif	
		
	bool Connect_PCDMIS(void);
	void Disconnect_PCDMIS(void);
	bool Open_PCDMIS_Program(TAutomation * const program);
	bool Close_PCDMIS_Program(TAutomation * const program);
	
	bool Connect_PCDMIS_Machine_Events(TAutomation * const program);
	void Disconnect_PCDMIS_Machine_Events(void);
	
	bool Open_Database(const QString &file_name);
	void Close_Database(void);
	void Write_Active_DatabaseItem(void);
	void Update_Selected_Text_Data(void);
	
	void Set_Status_Text(const QString &text);

// NOT IMPLEMENTED
	TCMMUsage(const TCMMUsage&);
	TCMMUsage& operator=(const TCMMUsage&);
};

#endif
