/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2023  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#ifndef DATABASEHEADERFILE
#define DATABASEHEADERFILE

#include <QString>
#include <QStringList>
#include <vector>
#include <QDate>
#include <QTime>

#include "databaseitem.h"

class QSqlDatabase;

class TDatabase
{
public:
	
// CREATORS
	TDatabase(void);
	~TDatabase(void);
	
// ACCESSORS
	bool Is_Connected(void) const;
	
	bool Program_Exists(const QString &name,const QString &date = QString(),const QString &time = QString()) const;
	bool Program_Exists(const QString &name,const QDateTime &date_time) const;
	
	QStringList Dates(void) const;
	QStringList Programs(const QStringList &dates) const;
	QStringList Program_Times(const QString &name,const QString &date) const;
	std::vector<TDatabaseItem> Program_Data(const QString &name,const QString &date);
	TDatabaseItem Program_Data(const QString &name,const QString &date,const QString &time,bool * const valid);
	int Software_Monitor_Time(bool * const valid);
	int Software_Run_Time(bool * const valid);
	
	QString Last_Error(void) const {return d_last_error;}
		
// MANIPULATORS
	bool Connect(const QString &file_name);
	bool Initialize(void);								// verifies required tables exist
	void Disconnect(void);
	void Clear(void);

	bool Add_Database_Item(const TDatabaseItem &item);
	bool Increment_Software_Monitor_Time(const int seconds);
	bool Increment_Software_Run_Time(const int seconds);
	
private:
	
	QString								d_database_instance_name;
	QString								d_database_file_name;
	
	mutable QSqlDatabase				*d_database;
	mutable QString						d_last_error;

	int Program_Id(const QString &name,const QString &date,const QString &time) const;
	int Program_Id(const QString &name,const QDateTime &date_time) const;
	
	static QString Date_To_String(const QDate &date);
	static QString Time_To_String(const QTime &time);
	static QDate String_To_Date(const QString &date);
	static QTime String_To_Time(const QString &time);
	static QDateTime String_To_DateTime(const QString &date,const QString &time);


// NOT IMPLEMENTED
	TDatabase(const TDatabase&);
	TDatabase& operator=(const TDatabase&);
};


#endif
