/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2023  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#include <assert.h>

#include "databaseitem.h"

TDatabaseItem::TDatabaseItem(void)
{
	d_execution_time = 0;
	d_idle_time = 0;
	d_executed_point_count = 0;
}

TDatabaseItem::TDatabaseItem(
	const TDatabaseItem					&rhs)
{
	if(&rhs != this)
	{
		d_name = rhs.d_name;
		d_revision = rhs.d_revision;
		d_date_time = rhs.d_date_time;
		d_execution_time = rhs.d_execution_time;
		d_idle_time = rhs.d_idle_time;
		d_executed_point_count = rhs.d_executed_point_count;
		d_error_messages = rhs.d_error_messages;
	}
}

TDatabaseItem& TDatabaseItem::operator=(
	const TDatabaseItem					&rhs)
{
	if(&rhs != this)
	{
		d_name = rhs.d_name;
		d_revision = rhs.d_revision;
		d_date_time = rhs.d_date_time;
		d_execution_time = rhs.d_execution_time;
		d_idle_time = rhs.d_idle_time;
		d_executed_point_count = rhs.d_executed_point_count;
		d_error_messages = rhs.d_error_messages;
	}
	
	return *this;
}

TDatabaseItem::~TDatabaseItem(void)
{
}

QString TDatabaseItem::Date(void) const
{
	QString								date;
	
	if(this->Date_Time_Valid())
	{
		date = d_date_time.toString(QStringLiteral("dd MMM yyyy"));
	}
	else
	{
		date = QStringLiteral("<invalid>");
	}
	
	return date;
}

QString TDatabaseItem::Time(void) const
{
	QString								time;
	
	if(this->Date_Time_Valid())
	{
		time = d_date_time.toString(QStringLiteral("hh mm ss ap"));
	}
	else
	{
		time = QStringLiteral("<invalid>");
	}
	
	return time;
}
	
QString TDatabaseItem::Error_Message(
	const int 							index) const
{
	assert(!(index < 0));
	assert(index < d_error_messages.size());
	
	return d_error_messages[index];
}

void TDatabaseItem::Clear(void) 
{
	d_name.clear();
	d_revision.clear();
	d_date_time = QDateTime();

	d_execution_time = 0;
	d_idle_time = 0;
	d_executed_point_count = 0;

	d_error_messages.clear();
}

void TDatabaseItem::Set_Execution_Time(
	const int 							seconds)
{
	assert(!(seconds < 0));
	
	d_execution_time = seconds;
}

void TDatabaseItem::Set_Idle_Time(
	const int 							seconds)
{
	assert(!(seconds < 0));

	d_idle_time = seconds;
}

void TDatabaseItem::Set_Executed_Point_Count(
	const int 							count)
{
	assert(!(count < 0));

	d_executed_point_count = count;
}

void TDatabaseItem::Add_Error_Message(
	const QString 						&text)
{
	d_error_messages.push_back(text);
}

void TDatabaseItem::Clean_Strings(void)
{
	QStringList::iterator				iter;
	
	for(iter = d_error_messages.begin();iter != d_error_messages.end();++iter)
	{
		this->Clean_String(&(*iter));
	}
	this->Clean_String(&d_name);
	this->Clean_String(&d_revision);
}

QString TDatabaseItem::Clean_String(
	const QString						&s)
{
	QString								clean(s);
	
	TDatabaseItem::Clean_String(&clean);
	
	return clean;
}

void TDatabaseItem::Clean_String(
	QString								* const str)
{
	assert(str);
	
	str->remove('\'');
	str->remove('\"');
	str->remove('%');
	str->remove('*');
	str->remove('[');
	str->remove(']');
	str->remove('^');
	str->remove('\\');
	str->remove('/');
	str->remove(',');
	str->remove(':');
}



