/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2023  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#ifndef DATABASEITEMHEADERFILE
#define DATABASEITEMHEADERFILE

#include <QString>
#include <QStringList>
#include <QDateTime>

class TDatabaseItem
{
public:
	
// CREATORS
	TDatabaseItem(void);
	TDatabaseItem(const TDatabaseItem&);
	TDatabaseItem& operator=(const TDatabaseItem&);
	~TDatabaseItem(void);
	
// ACCESSORS
	QString Name(void) const {return d_name;}
	QString Revision(void) const {return d_revision;}
	QDateTime Date_Time(void) const {return d_date_time;}
	QString Date(void) const;
	QString Time(void) const;
	bool Date_Time_Valid(void) const {return d_date_time.isValid();}
	
	int Execution_Time(void) const {return d_execution_time;}
	int Idle_Time(void) const {return d_idle_time;}
	int Executed_Point_Count(void) const {return d_executed_point_count;}
	QStringList Error_Messages(void) const {return d_error_messages;}
	
	int Error_Message_Count(void) const {return d_error_messages.size();}
	QString Error_Message(const int index) const;
	
// MANIPULATORS
	void Clear(void);
	
	void Set_Name(const QString &text) {d_name = text;}
	void Set_Revision(const QString &text) {d_revision = text;}
	void Set_Date_Time(const QDateTime &date_time) {d_date_time = date_time;}

	void Set_Execution_Time(const int seconds);
	void Set_Idle_Time(const int seconds);
	void Set_Executed_Point_Count(const int count);
	
	void Increment_Executed_Point_Count(void) {++d_executed_point_count;}

	void Add_Error_Message(const QString &text);
	
	void Clean_Strings(void);								// removes characters that would be problematic
	static QString Clean_String(const QString &s);			// removes characters that would be problematic
	
private:
	QString								d_name;
	QString								d_revision;
	QDateTime							d_date_time;
	int									d_execution_time;
	int									d_idle_time;
	int									d_executed_point_count;
	QStringList							d_error_messages;
	
	static void Clean_String(QString * const str);
	
// NOT IMPLEMENTED
};

#endif
