/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2024  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#include <QApplication>
#include <assert.h>

#ifdef Q_OS_WIN
#include <windows.h>
#endif

#include "monitorprocess.h"

TMonitorProcess::TMonitorProcess(
	const QObject						*parent)
:QThread(const_cast<QObject*>(parent))
{
}

TMonitorProcess::~TMonitorProcess(void)
{
}

void TMonitorProcess::run(void)
{
#ifdef Q_OS_WIN
	HWND								hwnd;
#endif
	bool								init(true);
	bool								visible;
	int									cntr;
	static const int					MONITOR_INTERVAL(1000);
	static const int					STOP_INTERVAL(100);
	static const int					STOP_INTERVAL_COUNT(MONITOR_INTERVAL / STOP_INTERVAL);
	
	d_class_visible = false;
	d_stop_thread = false;
	
	assert(STOP_INTERVAL_COUNT > 0);
	
	do
	{
		if(d_class_name.length())
		{
#ifdef Q_OS_WIN
		
			hwnd = ::FindWindowW(reinterpret_cast<const wchar_t*>(d_class_name.utf16()),0);

			if(hwnd)
			{
				visible = (0 != ::IsWindowVisible(hwnd));
			}
			else
			{
				visible = false;
			}
		
#else
			visible = true;
		
#endif
			
			if(init)
			{
				emit Class_Visible(visible);
				init = false;
			}
			else if(visible != d_class_visible)
			{
				if(visible)
				{
					this->msleep(MONITOR_INTERVAL);  // signal for first appearace delayed.  This may not be necessary (?).
				}
				
				emit Class_Visible(visible);
			}
			
			d_class_visible = visible;
		}
		
		for(cntr = 0;cntr < STOP_INTERVAL_COUNT;++cntr)
		{
			this->msleep(STOP_INTERVAL);
			
			if(d_stop_thread)
			{
				break;
			}
		}
		
	}while(!d_stop_thread);
}
